#include "editfilmdialog.h"
#include "ui_editfilmdialog.h"

editFilmDialog::editFilmDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::editFilmDialog)
{
    ui->setupUi(this);
    this->show();

    if (!m_db.open())        qDebug()<<"Error: DB not connectred";
    else                     qDebug()<<"DB connected succesfully";
    m_query = new QSqlQuery(m_db);
    tableView();
    connect(ui->tableView, &QTableView::clicked, this, &editFilmDialog::update_tableView);

}

editFilmDialog::~editFilmDialog()
{
    delete ui;
}

void editFilmDialog::tableView()
{
    QSqlQueryModel* result_model = new QSqlQueryModel(this);
    m_query->exec("SELECT title, director, duration, year FROM films;");
    result_model->setQuery(*m_query);
    ui->tableView->setModel(result_model);
}


void editFilmDialog::update_tableView(const QModelIndex &index)
{
    QVariant title = index.data();
    int col = index.column();

    if (col == 0){
        ui->filmEdit->setText(title.toString());
    }
    if (col == 1){
        ui->directorEdit->setText(title.toString());
    }
    if (col == 2){
        ui->durationEdit->setText(title.toString());
    }
    if (col == 3){
        ui->yearEdit->setText(title.toString());
    }
}

void editFilmDialog::on_addFilmButton_clicked()
{
    QString    filmName = ui->filmEdit->text();
    QString    duration = ui->durationEdit->text();
    QString    director = ui->directorEdit->text();
    QString    year = ui->yearEdit->text();
    qDebug()<<filmName<<duration<<director<<year;
    m_query->prepare("INSERT INTO Films(title, director, duration, year) VALUES (:filmName, :director, :duration, :year)");
    m_query->bindValue(":filmName", filmName);
    m_query->bindValue(":duration", duration.toInt());
    m_query->bindValue(":director", director);
    m_query->bindValue(":year", year.toInt());
    qDebug()<<m_query;

    if (!m_query->exec() && !m_query->next()){
        qDebug() << "Error executing query: " << m_query->lastError().text();
        ui->errorLabel->setText("Нельзя добавить фильм: фильм уже существует");

    }
    else{
        ui->errorLabel->setText("Успешно добавлен фильм");
    }

    tableView();
}


void editFilmDialog::on_deleteFilbButton_clicked()
{
    QString    filmName = ui->filmEdit->text();
    QString    duration = ui->durationEdit->text();
    QString    director = ui->directorEdit->text();
    QString    year = ui->yearEdit->text();
    qDebug()<<filmName<<duration<<director<<year;

    m_query->prepare("DELETE FROM Films WHERE title = :filmName AND director = :director;");
    m_query->bindValue(":filmName", filmName);
    m_query->bindValue(":director", director);
    //qDebug()<<m_query;


    if (!m_query->exec() && !m_query->next()){
        qDebug() << "Error executing query: " << m_query->lastError().text();
        ui->errorLabel->setText("Невозможно удалить: на фильм уже куплены билеты");

//        if (m_query->lastError().text() == "")
//            ui->errorLabel->setText("Невозможно удалить: нет такого фильма");
//        if (m_query->lastError().text() == "ERROR:  update or delete on table \"films\" violates foreign key constraint \"actorsfilms_film_id_fkey\" on table \"actorsfilms\"\nDETAIL:  Key (film_id)=(3) is still referenced from table \"actorsfilms\".\n(23503) QPSQL: Unable to create query")
//            ui->errorLabel->setText("Невозможно удалить: на фильм уже куплены билеты");
    }
    else{
        ui->errorLabel->setText("Успешно удалён фильм");
    }
    tableView();
}

